"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.hasOwnProperties = exports.apiRequest = exports.jsonContentTypes = exports.__assign = undefined;
exports.find = find;
exports.findIndex = findIndex;

var _assign = require("./assign");

var _rxjsImports = require("./rxjs-imports");

exports.__assign = _assign.__assign;
var jsonContentTypes = exports.jsonContentTypes = ["application/json", "application/vnd.api+json"];
var apiRequest = exports.apiRequest = function (url, options) {
    if (options === void 0) {
        options = {};
    }
    return _rxjsImports.Observable.ajax((0, _assign.__assign)({ url: url }, options, { responseType: "json" })).map(function (res) {
        if (res.status >= 200 && res.status < 300) {
            if (res.status === 204) {
                return res;
            }
            var header_1 = res.xhr.getResponseHeader("Content-Type");
            if (typeof header_1 === "string" && jsonContentTypes.some(function (contentType) {
                return header_1.indexOf(contentType) > -1;
            })) {
                return res.response;
            }
        }
        return res;
    });
};
var hasOwnProperties = exports.hasOwnProperties = function (obj, propertyTree) {
    if (obj instanceof Object === false) {
        return false;
    }
    var property = propertyTree[0];
    var hasProperty = obj.hasOwnProperty(property);
    if (hasProperty) {
        if (propertyTree.length === 1) {
            return hasProperty;
        }
        return hasOwnProperties(obj[property], propertyTree.slice(1));
    }
    return false;
};
function find(array, predicate) {
    for (var i = 0; i < array.length; i += 1) {
        if (predicate(array[i], i, array)) {
            return array[i];
        }
    }
    return undefined;
}
function findIndex(array, predicate) {
    if (array.length === 0) {
        return -1;
    }
    for (var i = 0; i < array.length; i++) {
        if (predicate(array[i], i, array)) {
            return i;
        }
    }
    return -1;
}
//# sourceMappingURL=utils.js.map